@@ -4,7 +4,6 @@
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 #include "plaintexteditor.h"
-#include "kpimtextedit_debug.h"
 
 #include "texteditor/commonwidget/textmessageindicator.h"
 #include <KConfig>
@@ -21,6 +20,9 @@
 #ifdef HAVE_KTEXTADDONS_TEXT_TO_SPEECH_SUPPORT
 #include <TextEditTextToSpeech/TextToSpeech>
 #endif
+#ifdef HAVE_KTEXTADDONS_TEXT_EMOTICONS_SUPPORT
+#include <TextEmoticonsWidgets/EmoticonTextEditAction>
+#endif
 #include <Sonnet/Dialog>
 #include <sonnet/backgroundchecker.h>
 
@@ -217,7 +219,14 @@ void PlainTextEditor::contextMenuEvent(QContextMenuEvent *event)
             d->webshortcutMenuManager->setSelectedText(selectedText);
             d->webshortcutMenuManager->addWebShortcutsToMenu(popup);
         }
-
+#ifdef HAVE_KTEXTADDONS_TEXT_EMOTICONS_SUPPORT
+        if (emojiSupport()) {
+            popup->addSeparator();
+            auto action = new TextEmoticonsWidgets::EmoticonTextEditAction(this);
+            popup->addAction(action);
+            connect(action, &TextEmoticonsWidgets::EmoticonTextEditAction::insertEmoticon, this, &PlainTextEditor::slotInsertEmoticon);
+        }
+#endif
         addExtraMenuEntry(popup, event->pos());
         popup->exec(event->globalPos());
 
@@ -225,6 +234,23 @@ void PlainTextEditor::contextMenuEvent(QContextMenuEvent *event)
     }
 }
 
+void PlainTextEditor::slotInsertEmoticon(const QString &str)
+{
+    insertPlainText(str);
+}
+void PlainTextEditor::setEmojiSupport(bool b)
+{
+    if (b) {
+        d->supportFeatures |= Emoji;
+    } else {
+        d->supportFeatures = (d->supportFeatures & ~Emoji);
+    }
+}
+
+bool PlainTextEditor::emojiSupport() const
+{
+    return d->supportFeatures & Emoji;
+}
 void PlainTextEditor::addExtraMenuEntry(QMenu *menu, QPoint pos)
 {
     Q_UNUSED(menu)
@@ -786,6 +812,7 @@ void PlainTextEditor::addIgnoreWordsToHighLighter()
 
 void PlainTextEditor::setHighlighter(Sonnet::Highlighter *_highLighter)
 {
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     Sonnet::SpellCheckDecorator *decorator = createSpellCheckDecorator();
     delete decorator->highlighter();
     decorator->setHighlighter(_highLighter);
@@ -795,6 +822,9 @@ void PlainTextEditor::setHighlighter(Sonnet::Highlighter *_highLighter)
     _highLighter->setParent(decorator);
     d->richTextDecorator = decorator;
     addIgnoreWordsToHighLighter();
+#else
+#pragma "NEED TO FIX IN QT6"
+#endif
 }
 
 void PlainTextEditor::focusInEvent(QFocusEvent *event)
